summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreebudget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/widgets/kmymoneyaccounttreebudget.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreebudget.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebudget.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebudget.h b/kmymoney2/widgets/kmymoneyaccounttreebudget.h
index 470a8f8..fc4a813 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebudget.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreebudget.h
@@ -41,7 +41,7 @@ class KMyMoneyAccountTreeBudget : public KMyMoneyAccountTreeBase
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyAccountTreeBudget(TQWidget* tqparent = 0, const char *name = 0);
+ KMyMoneyAccountTreeBudget(TQWidget* parent = 0, const char *name = 0);
virtual ~KMyMoneyAccountTreeBudget() {}
public slots:
@@ -57,7 +57,7 @@ public:
* Constructor to be used to construct an account
* entry object for a budget.
*
* @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -68,13 +68,13 @@ public:
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
*/
- KMyMoneyAccountTreeBudgetItem(KMyMoneyAccountTreeBudgetItem *tqparent, const MyMoneyAccount& account, const MyMoneyBudget& budget, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity());
+ KMyMoneyAccountTreeBudgetItem(KMyMoneyAccountTreeBudgetItem *parent, const MyMoneyAccount& account, const MyMoneyBudget& budget, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity());
/**
* Constructor to be used to construct an account
* entry object for a budget.
*
* @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -85,7 +85,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeBudgetItem(KListView *tqparent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeBudgetItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyBudget &budget, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeBudgetItem();
@@ -57,7 +57,7 @@ public:
* entry object for a budget.
*
- * @param tqparent pointer to the tqparent KAccountListView object this entry should be
+ * @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -68,13 +68,13 @@ public:
* entry object for a budget.
*
- * @param tqparent pointer to the tqparent KAccountListView object this entry should be
+ * @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which